Class: Github::Ext

Inherits:
Object
  • Object
show all
Defined in:
lib/mushin_ext_github.rb

Instance Method Summary collapse

Constructor Details

#initialize(app = nil, opts = {}, params = {}) ⇒ Ext

Returns a new instance of Ext.



9
10
11
12
13
# File 'lib/mushin_ext_github.rb', line 9

def initialize app=nil, opts={}, params={}
  @app 		= app
  @opts 	= opts
  @params 	= params 
end

Instance Method Details

#call(env) ⇒ Object



14
15
16
17
18
19
20
21
22
23
24
# File 'lib/mushin_ext_github.rb', line 14

def call env 
  env ||= Hash.new 
  # write inbound code
  if @opts[:cqrs] == :cqrs_query then
    # write your code here if it is a cqrs query
  else 
    # write your code here if it is a cqrs command 
  end
  @app.call(env)
  # write outbound code
end